package Nagios::Status::Service;

use Moose;

use overload '""' => \&stringify;

has 'description'   => ( is => 'ro', isa => 'Str', required => 1 );
has 'state'         => ( is => 'ro', isa => 'Int', required => 1 );
has 'plugin_output' => ( is => 'ro' );

sub stringify { 
  my $self = shift;
  sprintf "%s%s", $self->state == 2 ? '!' : $self->state == 1 ? '*' : '',
                  $self->description;
}

__PACKAGE__->meta->make_immutable;

1;

=head1 NAME

Nagios::Status::Service - individual Nagios service status

=head1 SYNOPSIS

     $nss = Nagios::Status::Service->new(
        description     => 'kernel',
        state           => 1,
        plugin_output   => 'KERNEL_VERSION WARNING',
     );

     print $nss->description;
     warn if $nss->state;

=head1 SEE ALSO

Nagios::Object, Nagios::StatusLog

=head1 COPYRIGHT AND LICENCE

Copyright 2009 Gavin Carr E<lt>gavin@openfusion.com.auE<gt>.

This software is free software, licensed under the same terms as Perl itself.

=cut

